@@ -1,3 +1,5 @@
+import copy
+
 import pytest
 
 import topside as top
@@ -157,7 +159,7 @@ def test_FC_name_overlap():
         }
     }
 
-    pressures = {3: 100}
+    pressures = {3: (100, False)}
     default_states = {'fill_valve': 'closed', 'remote_fill_valve': 'open'}
     plumb = top.PlumbingEngine(
         {'fill_valve': pc1, 'remote_fill_valve': pc2}, component_mapping, pressures, default_states)
@@ -193,7 +195,7 @@ def test_list_functions():
     }
 
     negative_pressure = -50
-    pressures = {3: negative_pressure}
+    pressures = {3: (negative_pressure, False)}
     default_states = {'valve1': 'closed', 'valve2': 'open'}
     plumb = top.PlumbingEngine(
         {'valve1': pc1, 'valve2': pc2}, component_mapping, pressures, default_states)
@@ -224,3 +226,20 @@ def test_list_functions():
     assert plumb.errors() == {
         invalid.InvalidNodePressure(f"Negative pressure {negative_pressure} not allowed.", 3)
     }
+
+
+def test_components():
+    plumb = test.two_valve_setup(1, 1, 1, 1, 1, 1, 1, 1)
+    original_components = copy.deepcopy(plumb.component_dict)
+    queried_components = plumb.components()
+
+    assert list(original_components.keys()) == list(queried_components.keys())
+
+    queried_components.pop('valve1')
+
+    assert len(queried_components) == 1
+    assert len(original_components) == 2
+
+    # make sure that changes to the returned dict aren't propagated through to the original
+    assert list(original_components.keys()) == list(plumb.component_dict.keys())
+    assert list(original_components.keys()) == list(plumb.components().keys())
